@@ -15,15 +15,14 @@ from .lrp import LRPCVInterpreter
 from .rollout import RolloutInterpreter
 from .transition_attention_maps import TAMInterpreter
 from .consensus import ConsensusInterpreter
+from .generic_attention import GAInterpreter
 
 __all__ = [
-    "Interpreter",
-    "InputGradientInterpreter", "InputOutputInterpreter", "IntermediateLayerInterpreter",
-    "LIMECVInterpreter", "LIMENLPInterpreter", "GradCAMInterpreter", "IntGradCVInterpreter",
-    "IntGradNLPInterpreter", "SmoothGradInterpreter", "OcclusionInterpreter",
-    "GradShapCVInterpreter", "GradShapNLPInterpreter", "ScoreCAMInterpreter",
-    "LRPCVInterpreter", "RolloutInterpreter", "TAMInterpreter",
-    "SmoothGradInterpreterV2", 'ConsensusInterpreter'
+    "Interpreter", "InputGradientInterpreter", "InputOutputInterpreter", "IntermediateLayerInterpreter",
+    "LIMECVInterpreter", "LIMENLPInterpreter", "GradCAMInterpreter", "IntGradCVInterpreter", "IntGradNLPInterpreter",
+    "SmoothGradInterpreter", "OcclusionInterpreter", "GradShapCVInterpreter", "GradShapNLPInterpreter",
+    "ScoreCAMInterpreter", "LRPCVInterpreter", "RolloutInterpreter", "TAMInterpreter", "SmoothGradInterpreterV2",
+    'ConsensusInterpreter', 'GAInterpreter'
 ]
 
 try:
@@ -32,9 +31,8 @@ try:
     from .lime_prior import LIMEPriorInterpreter
     from .forgetting_events import ForgettingEventsInterpreter
     from ._normlime_base import NormLIMECVInterpreter, NormLIMENLPInterpreter
-    __all__ += ["LIMEPriorInterpreter", "ForgettingEventsInterpreter", 
-                "NormLIMECVInterpreter", "NormLIMENLPInterpreter"]
+    __all__ += [
+        "LIMEPriorInterpreter", "ForgettingEventsInterpreter", "NormLIMECVInterpreter", "NormLIMENLPInterpreter"
+    ]
 except ModuleNotFoundError:
-    print(
-        "Warning: Paddle should be installed before using some Interpreters."
-    )
+    print("Warning: Paddle should be installed before using some Interpreters.")
